@@ -70,8 +70,8 @@ generate_pot() {
                 -o $potfile \
                 $(find ../../ -type f \( -name "*.php" -o -name "*.inc" \) -not -path "../../config/*" -not -path "../../docs/*" -not -path "../../lib/components/*" -not -path "../../vendor/*" -not -path "../../tests/*" | sort)
     if [[ $? -eq 0 ]]; then
-        #echo -e "\033[32m Pot file creation succeeded. Adding 'translatable-database-strings.txt\033[0m"
-        #cat $tdstxt >> $potfile
+        echo -e "\033[32m Pot file creation succeeded. Adding 'translatable-database-strings.txt\033[0m"
+        cat $tdstxt >> $potfile
         echo -e "\033[32m Pot file creation succeeded. Adding 'untranslated-strings.txt\033[0m"
         cat $xhtmltxt >> $potfile
         echo -e "\n\033[32m Done, you are able now to use the messages.pot for further translation tasks.\033[0m"
